@@ -486,6 +486,8 @@ collate_branches(rev_ref **branches, int nbranch,
 		     c->master->name, branch->ref_name);
 	    continue;
 	}
+
+	// cppcheck-suppress nullPointer
 	REVISION_T_PACK(revisions[n], (cvs_commit *)NULL);
     }
 
@@ -602,6 +604,7 @@ collate_branches(rev_ref **branches, int nbranch,
 	    REVISION_T_PACK(revisions[n], to);
 	    continue;
 	Kill:
+	    // cppcheck-suppress nullPointer
 	    REVISION_T_PACK(revisions[n], (cvs_commit *)NULL);
 	}
 
@@ -888,9 +891,9 @@ rev_tag_search(tag_t *tag, cvs_commit **revisions, git_repo *gl)
 	continue;
     r->next = tag_branch;
     g->author = atom("cvs-fast-export");
-    size_t len = strlen(tag->name) + 41;
+    size_t len = strlen(tag->name) + 42;
     char *log = xmalloc(len, __func__);
-    snprintf(log, len, "Synthetic commit for incomplete tag %s", tag->name);
+    snprintf(log, len, "Synthetic commit for incomplete tag %s\n", tag->name);
     g->log = atom(log);
     free(log);
 }
@@ -1113,7 +1116,7 @@ collate_to_changesets(cvs_master *masters, size_t nmasters, int verbose)
  * Generate a list of files in uniq that aren't in common
  */
 static cvs_commit_list *
-rev_uniq_file(git_commit *uniq, git_commit *common, int *nuniqp)
+rev_uniq_file(git_commit *uniq, git_commit const *common, int *nuniqp)
 {
     int nuniq = 0;
     cvs_commit_list   *head = NULL, **tail = &head, *fl;
