@@ -216,13 +216,14 @@ enum expand_mode expand_override(char const *s)
 {
     if (s != NULL)
     {
+        /* Don't modify this without syncing the EXPAND constants in cvs.h */
 	char *const expand_names[] = {"kv", "kvl", "k", "v", "o", "b"};
 	int i;
 	for (i=0; i < 6; ++i)
 	    if (strcmp(s,expand_names[i]) == 0)
 		return(enum expand_mode) i;
     }
-    return EXPANDUNSPEC;
+    return EXPANDKB;
 }
 
 static char const *basefilename(const char* const p)
@@ -439,6 +440,7 @@ static enum edit_op parse_next_delta_command(editbuffer_t *eb,
     while (in_buffer_getc(eb) != '\n')
 	;
 
+    // cppcheck-suppress invalidTestForOverflow
     if (!nlines || line1+nlines < line1)
 	fatal_error("corrupt delta in %s", eb->Gfilename);
 
@@ -824,21 +826,23 @@ static uchar *
 load_text(editbuffer_t *eb, const cvs_text *text)
 {
     FILE *f = fopen(text->filename, "rb");
-    uchar *data;
 
     if (!f)
 	fatal_error("Cannot open %s", text->filename);
-    if (fseek(f, text->offset, SEEK_SET) == -1)
-        fatal_system_error("fseek %s", text->filename);
-    data = xmalloc(text->length + 2, __func__);
-    if (fread(data, 1, text->length, f) != text->length)
-        fatal_system_error("short read %s", text->filename);
-    if (data[0] != '@') fatal_error("doesn't start with '@'");
-    if (data[text->length - 1] != '@') fatal_error("doesn't end with '@'");
-    data[text->length] = ' ';
-    data[text->length + 1] = '\0';
-    fclose(f);
-    return data;
+    else {
+	uchar *data;
+	if (fseek(f, text->offset, SEEK_SET) == -1)
+	    fatal_system_error("fseek %s", text->filename);
+	data = xmalloc(text->length + 2, __func__);
+	if (fread(data, 1, text->length, f) != text->length)
+	    fatal_system_error("short read %s", text->filename);
+	if (data[0] != '@') fatal_error("doesn't start with '@'");
+	if (data[text->length - 1] != '@') fatal_error("doesn't end with '@'");
+	data[text->length] = ' ';
+	data[text->length + 1] = '\0';
+	fclose(f);
+	return data;
+    }
 }
 
 static void
@@ -1052,10 +1056,7 @@ static node_t *generate_setup(generator_t *gen)
 
 	eb->current = eb->stack;
 	eb->Gfilename = gen->master_name;
-	if (gen->expand != EXPANDUNSPEC)
-	    eb->Gexpand = gen->expand;
-	else
-	    eb->Gexpand = EXPANDKKV;
+	eb->Gexpand = gen->expand;
 	eb->Gabspath = NULL;
 	Gline(eb) = NULL; Ggap(eb) = Ggapsize(eb) = Glinemax(eb) = 0;
     }
@@ -1091,7 +1092,7 @@ void generate_files(generator_t *gen,
     for (;;) {
 	if (node->commit != NULL && !node->commit->dead) {
 	    out_buffer_init(eb);
-	    if (eb->Gexpand < EXPANDKO)
+	    if (eb->Gexpand != EXPANDKB && eb->Gexpand != EXPANDKO)
 		expandedit(eb);
 	    else
 		snapshotedit(eb);
