@@ -135,7 +135,7 @@ rev_list_file(rev_file *file, analysis_t *out, cvs_master *cm, rev_master *rm)
 
     cvs = xcalloc(1, sizeof(cvs_file), __func__);
     cvs->gen.master_name = file->name;
-    cvs->gen.expand = EXPANDUNSPEC;
+    cvs->gen.expand = EXPANDKB;
     cvs->export_name = file->rectified;
     cvs->mode = buf.st_mode;
     cvs->verbose = verbose;
@@ -299,7 +299,7 @@ file_compare(const void *f1, const void *f2)
     return path_deep_compare(r1.rectified, r2.rectified);
 }
 
-void analyze_masters(int argc, char *argv[], 
+void analyze_masters(int argc, const char *argv[],
 			  import_options_t *analyzer, 
 			  forest_t *forest)
 /* main entry point; collect and parse CVS masters */
