@@ -1,44 +1,48 @@
 #!/usr/bin/env python3
 ## Test handling of vendor branches
-#
-# This test was swiped from the git 1.8.1 tree, then modified to exercise
-# lifters directly rather than through git-cvsimport.
-#
-# Description of the files in the repository:
-#
-#    imported-once.txt:
-#
-#       Imported once.  1.1 and 1.1.1.1 should be identical.
-#
-#    imported-twice.txt:
-#
-#       Imported twice.  HEAD should reflect the contents of the
-#       second import (i.e., have the same contents as 1.1.1.2).
-#
-#    imported-modified.txt:
-#
-#       Imported, then modified on HEAD.  HEAD should reflect the
-#       modification.
-#
-#    imported-modified-imported.txt:
-#
-#       Imported, then modified on HEAD, then imported again.
-#
-#    added-imported.txt,v:
-#
-#       Added with 'cvs add' to create 1.1, then imported with
-#       completely different contents to create 1.1.1.1, therefore the
-#       vendor branch was never the default branch.
-#
-#    imported-anonymously.txt:
-#
-#       Like imported-twice.txt, but with a vendor branch whose branch
-#       tag has been removed.
-#
-# Note: Without the -t 0 option this test has intermittent failures.
-# This is due to commits with identical timestamps
-# being canonicalized backwards from their topo order.
+'''
 
+This test was swiped from the git 1.8.1 tree, then modified to exercise
+lifters directly rather than through git-cvsimport.
+
+Description of the files in the repository:
+
+   imported-once.txt:
+
+      Imported once.  1.1 and 1.1.1.1 should be identical.
+
+   imported-twice.txt:
+
+      Imported twice.  HEAD should reflect the contents of the
+      second import (i.e., have the same contents as 1.1.1.2).
+
+   imported-modified.txt:
+
+      Imported, then modified on HEAD.  HEAD should reflect the
+      modification.
+
+   imported-modified-imported.txt:
+
+      Imported, then modified on HEAD, then imported again.
+
+   added-imported.txt,v:
+
+      Added with 'cvs add' to create 1.1, then imported with
+      completely different contents to create 1.1.1.1, therefore the
+      vendor branch was never the default branch.
+
+   imported-anonymously.txt:
+
+      Like imported-twice.txt, but with a vendor branch whose branch
+      tag has been removed.
+
+Note: Without the -t 0 option this test has intermittent failures.
+This is due to commits with identical timestamps
+being canonicalized backwards from their topo order.
+'''
+
+
+# pylint: disable=multiple-imports
 import sys, testlifter
 
 testlifter.verbose += sys.argv[1:].count("-v")
